@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # lesspipe.sh, a preprocessor for less
-lesspipe_version=2.13
+lesspipe_version=2.14
 # Author: Wolfgang Friebel (wp.friebel AT gmail.com)
 
 has_cmd () {
@@ -11,7 +11,7 @@ fileext () {
 	fn=${1##*/}
 	case "$fn" in
 		.*.*) extension=${fn##*.} ;;
-		.*) extension= ;;
+		.*) extension=${fn#.} ;;
 		*.*) extension=${fn##*.} ;;
 	esac
 	echo "$extension"
@@ -449,7 +449,7 @@ has_colorizer () {
 	[[ $2 == plain || -z $2 ]] && return
 	prog=${LESSCOLORIZER%% *}
 
-	for i in bat batcat pygmentize source-highlight vimcolor code2color ; do
+	for i in nvimpager bat batcat pygmentize source-highlight vimcolor code2color ; do
 		[[ -z $prog || $prog == "$i" ]] && has_cmd "$i" && prog=$i
 	done
 	[[ "$2" =~ ^[0-9]*$ || -z "$2" ]] || lang=$2
@@ -460,20 +460,24 @@ has_colorizer () {
 			[[ -n $lang ]] && $prog --list-languages|sed 's/.*:/,/;s/$/,/'|grep -i ",$lang," > /dev/null && opt=(-l "$lang")
 			[[ -n $LESSCOLORIZER && $LESSCOLORIZER = *\ *--style=* ]] && style="${LESSCOLORIZER/* --style=/}"
 			[[ -z $style ]] && style=$BAT_STYLE
-			[[ -z $style ]] && style=plain
 			[[ -n $LESSCOLORIZER && $LESSCOLORIZER = *\ *--theme=* ]] && theme="${LESSCOLORIZER/* --theme=/}"
 			[[ -z $theme ]] && theme=$BAT_THEME
-			[[ -z $theme ]] && theme=ansi
 			if [[ -r "$HOME/.config/bat/config" ]]; then
-				grep -q -e '^--style' "$HOME/.config/bat/config" || opt+=(--style="${style%% *}")
-				grep -q -e '^--theme' "$HOME/.config/bat/config" || opt+=(--theme="${theme%% *}")
+				if [[ -z $style ]]; then
+					grep -q -e '^--style' "$HOME/.config/bat/config" || style=plain
+				fi
+				if [[ -z $theme ]]; then
+					grep -q -e '^--theme' "$HOME/.config/bat/config" || theme=ansi
+				fi
 			else
-				opt+=(--style="${style%% *}" --theme="${theme%% *}")
+				[[ -z $style ]] && style=plain
+				[[ -z $theme ]] && theme=ansi
 			fi
+			opt+=(--style="${style%% *}" --theme="${theme%%[|&;<>]*}")
 			opt+=("$COLOR" --paging=never "$1") ;;
 		pygmentize)
 			pygmentize -l "$lang" /dev/null &>/dev/null && opt=(-l "$lang") || opt=(-g)
-			[[ -n $LESSCOLORIZER && $LESSCOLORIZER = *-O\ *style=* ]] && style="${LESSCOLORIZER/*style=/}"
+			[[ -n $LESSCOLORIZER && $LESSCOLORIZER = *-[OP]\ *style=* ]] && style="${LESSCOLORIZER/*style=/}"
 			[[ -n $style ]] && opt+=(-O style="${style%% *}")
 			[[ $colors -ge 256 ]] && opt+=(-f terminal256)
 			[[ "$1" == - ]] || opt+=("$1") ;;
@@ -486,6 +490,9 @@ has_colorizer () {
 		code2color|vimcolor)
 			opt=("$1")
 			[[ -n "$3" ]] && opt=(-l "$3" "$1") ;;
+		nvimpager)
+			opt=(-c "$1")
+			[[ -n "$3" ]] && opt=(-c "$1" -c "set filetype=$3") ;;
 		*)
 			return ;;
 	esac
@@ -527,7 +534,7 @@ isfinal () {
 			{ has_cmd pdftohtml && has_htmlprog && cmd=(istemp ispdf "$1"); } ||
 			{ has_cmd pdfinfo && cmd=(istemp pdfinfo "$1"); } ;;
 		postscript)
-			has_cmd ps2ascii && nodash ps2ascii "$1" ;;
+			has_cmd ps2ascii && nodash ps2ascii "$1" 2>/dev/null ;;
 		java-applet)
 			# filename needs to end in .class
 			has_cmd procyon && t=$t.class && cat "$1" > "$t" && cmd=(procyon "$t") ;;
@@ -541,10 +548,10 @@ isfinal () {
 			{ has_cmd libreoffice && cmd=(isoffice2 "$1"); } ;;
 		pptx)
 			{ has_cmd pptx2md && t2=$(nexttmp) &&
-				{ has_cmd mdcat && istemp "pptx2md --disable-image --disable-wmf \
+				{ { has_cmd mdcat && istemp "pptx2md --disable-image --disable-wmf \
 					-o $t2" "$1" && cmd=(mdcat "$t2"); } ||
 				{ has_cmd pandoc && istemp "pptx2md --disable-image --disable-wmf \
-					-o $t2" "$1" && cmd=(pandoc -f markdown -t plain "$t2"); }; } ||
+					-o $t2" "$1" && cmd=(pandoc -f markdown -t plain "$t2"); } }; } ||
 			{ can_do_office && cmd=(isoffice "$1" ppt); } ;;
 		xlsx|ods)
 			{ has_cmd xlscat && cmd=(istemp "xlscat -L -R all" "$1"); } ||
@@ -603,7 +610,7 @@ isfinal () {
 			has_cmd openssl && cmd=(istemp "openssl req -text -noout -in" "$1") ;;
 		pgp)
 			has_cmd gpg && cmd=(gpg --decrypt --quiet --no-tty --batch --yes "$1") ;;
-		plist)
+		bplist|plist)
 			{ has_cmd plistutil && cmd=(istemp "plistutil -i" "$1"); } ||
 			{ has_cmd plutil && cmd=(istemp "plutil -p" "$1"); } ;;
 		mp3)
